Class: Cocina::Models::DescriptiveIdentifier
- Defined in:
- lib/cocina/models/descriptive_identifier.rb
Overview
Value model for descriptive identifiers. Same as DescriptiveValue but omits the identifier property to prevent infinite recursion.
Value model for descriptive identifiers. Same as DescriptiveValue but omits the identifier property to prevent infinite recursion.